==> create-react-plugin-0.0.3.tgz: package/src/lib/create_library.js <==
/*********
    * 
    * {COMPANY_NAME}. Confidential
    * ____
    * 
    *  Copyright {COMPANY_NAME}. 2020. All rights reserved
    * 
    * NOTICE:  All information contained herein is, and remains
    * the property of {COMPANY_NAME}. and its suppliers,
    * if any.  The intellectual and technical concepts contained
    * herein are proprietary to {COMPANY_NAME}.
    * and its suppliers and may be covered by U.S. and Foreign Patents,
    * patents in process, and are protected by trade secret or copyright law.
    * Dissemination of this information or reproduction of this material
    * is strictly forbidden unless prior written permission is obtained
    * from {COMPANY_NAME}.
*/
'use strict'
const DEFAULT_PARAMS = require("../data/default_package_params")
const fs = require('fs-extra')
const spinner = require('ora')();
const util = require('util');
const exec = util.promisify(require('child_process').exec);
const chalk = require('chalk')

module.exports = async (packageParams = DEFAULT_PARAMS) => {
    let dest = `${process.cwd()}/${packageParams.name}`;
    fs.ensureDir(dest).then(async () => {
        try {
            console.log(`
            
            `);
            spinner.start(`Copying template to ${dest}`);
            await fs.copy(`${__dirname}/../templates/default`, dest);
            spinner.succeed();

            let pkg = require(`${dest}/package.json`);
            pkg.name = packageParams.name;
            pkg.version = packageParams.version;
            pkg.author = packageParams.author;
            pkg.license = packageParams.license;
            pkg.repository = packageParams.repository;
            pkg.description = packageParams.description;
            pkg.keywords = packageParams.keywords.split(",");
            fs.writeFile(`${dest}/package.json`, JSON.stringify(pkg, null, 4), async err => {
                if (err) throw err;
                spinner.start(`Installing dependencies - npm install`);
                await exec('npm i', { cwd: `${dest}` });
                spinner.succeed();

                console.log(`
Your module has been created at ${dest}.
                
To get started, in one tab, run:
$ ${chalk.cyan(`cd ${packageParams.name} && npm start`)}
`)
            });
        } catch (err) {
            spinner.fail(`Unable to create ${packageParams.name} react library`);
            throw err;
        }
    }).catch(err => {
        spinner.fail(`Unable to create ${packageParams.name} react library`);
        throw err;
    })
}

==> create-react-plugin-0.0.5.tgz: package/src/lib/create_library.js <==
/*********
    * 
    * {COMPANY_NAME}. Confidential
    * ____
    * 
    *  Copyright {COMPANY_NAME}. 2020. All rights reserved
    * 
    * NOTICE:  All information contained herein is, and remains
    * the property of {COMPANY_NAME}. and its suppliers,
    * if any.  The intellectual and technical concepts contained
    * herein are proprietary to {COMPANY_NAME}.
    * and its suppliers and may be covered by U.S. and Foreign Patents,
    * patents in process, and are protected by trade secret or copyright law.
    * Dissemination of this information or reproduction of this material
    * is strictly forbidden unless prior written permission is obtained
    * from {COMPANY_NAME}.
*/
'use strict'
const DEFAULT_PARAMS = require("../data/default_package_params")
const fs = require('fs-extra')
const spinner = require('ora')();
const util = require('util');
const exec = util.promisify(require('child_process').exec);
const chalk = require('chalk')

module.exports = async (packageParams = DEFAULT_PARAMS) => {
    let dest = `${process.cwd()}/${packageParams.name}`;
    fs.ensureDir(dest).then(async () => {
        try {
            console.log(`
            
            `);
            spinner.start(`Copying template to ${dest}`);
            await fs.copy(`${__dirname}/../templates/default`, dest);
            spinner.succeed();

            let pkg = require(`${dest}/package.json`);
            pkg.name = packageParams.name;
            pkg.version = packageParams.version;
            pkg.author = packageParams.author;
            pkg.license = packageParams.license;
            pkg.repository = packageParams.repository;
            pkg.description = packageParams.description;
            pkg.keywords = packageParams.keywords.split(",");
            fs.writeFile(`${dest}/package.json`, JSON.stringify(pkg, null, 4), async err => {
                if (err) throw err;
                spinner.start(`Installing dependencies - npm install`);
                await exec('npm i', { cwd: `${dest}` });
                spinner.succeed();

                console.log(`
Your module has been created at ${dest}
                
To get started, in one tab, run:
$ ${chalk.cyan(`cd ${packageParams.name} && npm start`)}
`)
            });
        } catch (err) {
            spinner.fail(`Unable to create ${packageParams.name} react library`);
            throw err;
        }
    }).catch(err => {
        spinner.fail(`Unable to create ${packageParams.name} react library`);
        throw err;
    })
}
